@@ -74,7 +74,6 @@ test_that('Subset assignment of hux into hux preserves attributes', {
 
 
 test_that('Column names are not uglified', {
-  # skip('Can\'t solve this one at the moment.')
   ht <- hux('A long column name' = 1:3, 'Another name' = 1:3, add_colnames = TRUE)
   expect_match(to_screen(ht), 'A long column name', fixed = TRUE, all = FALSE)
   ht <- hux('A long column name' = 1:3, 'Another name' = 1:3, add_colnames = FALSE)
@@ -139,6 +138,13 @@ test_that('insert_column and insert_row work', {
   expect_false(bold(ht)[1, 2])
 })
 
+test_that('insert_column works with column names', {
+  ht_orig <- hux(a = 1:2, b = 1:2)
+  ht <- insert_column(ht_orig, 8, 9, after = "a")
+  expect_equivalent(ncol(ht), 3)
+  expect_equivalent(ht[, 2], huxtable(8:9))
+})
+
 test_that('Can add a column to a huxtable using standard replacement methods', {
   ht <- hux(a = 1:2, b = 1:2)
   expect_silent(ht$c <- 1:2)
